/*
   $Id: mysql-migration-queries.sql 2973 2006-11-29 09:24:26Z nicklas $

	Copyright (C) 2006 Johan Enell, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

   BASE is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 3
   of the License, or (at your option) any later version.

   BASE is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA  02111-1307, USA.

   ----------

   This file contains all statements used in the migration. 
   All statements are defined by a

   \/* statementId *\/
   SELECT .... FROM ... WHERE... ;

   There is no fancy selection method so make sure that the stsatementId 
   is written exactly as above, excluding the '\' ofcourse, no Extra whitespaces are allowed.
   In migrate.properties you specify which queryStatementFile to use. 
   
   Use this one if your base 1.2.* installation is on a MySQL database.

   @author Gregory

*/

/* verifySchemaVersion */
SELECT `baseVersion`, `schemaVersion`, `lastChanged` FROM `SchemaVersion`;


/* UserGroup
+------------+-------------+------+-----+------------+----------------+
| Field      | Type        | Null | Key | Default    | Extra          |
+------------+-------------+------+-----+------------+----------------+
| id         | int(11)     |      | PRI | NULL       | auto_increment |
| name       | varchar(30) | YES  | MUL | NULL       |                |
| descr      | text        |      |     |            |                |
| owner      | int(11)     |      |     | 0          |                |
| addedDate  | date        |      |     | 0000-00-00 |                |
| removed    | tinyint(1)  |      |     | 0          |                |
| accessMask | int(11)     |      |     | 0          |                |
| isAccount  | tinyint(1)  |      |     | 0          |                |
| byteQuota  | double      | YES  |     | NULL       |                |
| usedQuota  | double      | YES  |     | NULL       |                |
+------------+-------------+------+-----+------------+----------------+*/

/* countUsers */
SELECT count(*) FROM `UserGroup` WHERE `isAccount` = 1;


/* selectUsers */
SELECT  `id`,
	`name`, 
	`realName`, 
	`address`, 
	`descr`, 
	`email`, 
	`fax`, 
	`md5pass`, 
	`phone`, 
	`removed`, 
	`byteQuota`, 
	`activeUntil`, 
	`accessMask`
FROM 	`UserGroup`, 
	`UserAccount`  
WHERE 	`isAccount` = 1 
AND 	`UserGroup`.`id` = `UserAccount`.`userGroup`
ORDER BY `id`
LIMIT   ?,?;


/* selectGroupPrivileges */
SELECT `g`.`child`, `u`.`accessMask` as mask 
FROM 	`UserGroup` u, 
	`UserGroupParent` g 
WHERE 	`u`.`id` = `g`.`parent`;


/* countGroups */
SELECT count(*) FROM `UserGroup` WHERE `isAccount` = 0;

/* selectGroups */
SELECT `id`, `name`, `descr`, `removed`, `accessMask`, `byteQuota`
FROM `UserGroup` 
WHERE `isAccount` = 0
ORDER BY `id`;



/* UserGroupParent;
+------------+------------+------+-----+---------+-------+
| Field      | Type       | Null | Key | Default | Extra |
+------------+------------+------+-----+---------+-------+
| child      | int(11)    |      | PRI | 0       |       |
| parent     | int(11)    |      | PRI | 0       |       |
| isReviewer | tinyint(1) |      |     | 0       |       |
+------------+------------+------+-----+---------+-------+*/

/* selectUsersByGroup */
SELECT `child` FROM `UserGroupParent` WHERE `parent` = ?;

 

/* SampleAnnotation
+----------------+---------+------+-----+---------+-------+
| Field          | Type    | Null | Key | Default | Extra |
+----------------+---------+------+-----+---------+-------+
| sample         | int(11) |      | PRI | 0       |       |
| annotationType | int(11) |      | PRI | 0       |       |
| annotation     | text    |      |     |         |       |
+----------------+---------+------+-----+---------+-------+*/

/* selectSampleAnnotations */
SELECT  `sample`, `annotationType`, `annotation` 
FROM `SampleAnnotation` 
ORDER BY `sample`, `annotationType`
LIMIT ?,?;


/* countSampleAnnotations */
SELECT count(*) FROM `SampleAnnotation`;



/* SampleAnnotationType
+--------------+-----------------------+------+-----+------------+----------------+
| Field        | Type                  | Null | Key | Default    | Extra          |
+--------------+-----------------------+------+-----+------------+----------------+
| id           | int(11)               |      | PRI | NULL       | auto_increment |
| name         | varchar(80)           |      | MUL |            |                |
| valueType    | enum('i','f','t','e') |      |     | i          |                |
| options      | text                  |      |     |            |                |
| defaultValue | text                  |      |     |            |                |
| descr        | text                  |      |     |            |                |
| owner        | int(11)               |      |     | 0          |                |
| addedDate    | date                  |      |     | 0000-00-00 |                |
| removed      | tinyint(1)            |      |     | 0          |                |
| gid          | int(11)               |      |     | 0          |                |
| groupAccess  | tinyint(1)            |      |     | 0          |                |
| worldAccess  | tinyint(1)            |      |     | 0          |                |
+--------------+-----------------------+------+-----+------------+----------------+ */

/* countSampleAnnotationTypes */
SELECT count(*) FROM `SampleAnnotationType`;


/* selectSampleAnnotationTypes */
SELECT 	`id`, `owner`, `gid`, `groupAccess`, `worldAccess`, `name`, `descr`, `removed`, 
	`valueType`, 
	`options`, 
	`defaultValue`
FROM SampleAnnotationType
ORDER BY `id`;


/* ArrayBatch
+----------------+--------------+------+-----+---------------------+----------------+
| Field          | Type         | Null | Key | Default             | Extra          |
+----------------+--------------+------+-----+---------------------+----------------+
| id             | int(11)      |      | PRI | NULL                | auto_increment |
| arrayType      | int(11)      |      | MUL | 0                   |                |
| descr          | text         |      |     |                     |                |
| printStartDate | datetime     |      |     | 0000-00-00 00:00:00 |                |
| printEndDate   | datetime     |      |     | 0000-00-00 00:00:00 |                |
| owner          | int(11)      |      |     | 0                   |                |
| name           | varchar(80)  |      | MUL |                     |                |
| addedDate      | date         |      |     | 0000-00-00          |                |
| surfaceType    | varchar(255) |      |     |                     |                |
| protocol       | int(11)      |      |     | 0                   |                |
| notes          | text         |      |     |                     |                |
| removed        | tinyint(1)   |      |     | 0                   |                |
| gid            | int(11)      |      |     | 0                   |                |
| groupAccess    | tinyint(1)   |      |     | 0                   |                |
| worldAccess    | tinyint(1)   |      |     | 0                   |                |
+----------------+--------------+------+-----+---------------------+----------------+*/

/* countArrayBatches */
SELECT count(*) FROM ArrayBatch;


/* selectArrayBatches */
SELECT 	`id`, `owner`, `gid`, `groupAccess`, `worldAccess`, `name`, `descr`, `removed`, 
	`arrayType`, 
	`printStartDate`, 
	`printEndDate`, 
	`surfaceType`, 
	`protocol`, 
	`notes` 
FROM 	`ArrayBatch`
ORDER BY `id`
LIMIT 	?,?;



/* ArrayBlock
+-----------------+-------------+------+-----+---------+-------+
| Field           | Type        | Null | Key | Default | Extra |
+-----------------+-------------+------+-----+---------+-------+
| arrayType       | int(11)     |      | PRI | 0       |       |
| blockNum        | smallint(6) |      | PRI | 0       |       |
| xOrigin         | float       |      |     | 0       |       |
| yOrigin         | float       |      |     | 0       |       |
| featureDiameter | float       |      |     | 0       |       |
| xFeatures       | float       |      |     | 0       |       |
| xSpacing        | float       |      |     | 0       |       |
| yFeatures       | float       |      |     | 0       |       |
| ySpacing        | float       |      |     | 0       |       |
| metaRow         | smallint(6) |      |     | 0       |       |
| metaColumn      | smallint(6) |      |     | 0       |       |
+-----------------+-------------+------+-----+---------+-------+ */

/* selectArrayBlocksByArrayType */
SELECT 	`arrayType`, 
	`blockNum`, 
	`xOrigin`, 
	`yOrigin`, 
	`featureDiameter`, 
	`xFeatures`,
	`xSpacing`, 
	`yFeatures`, 
	`ySpacing`, 
	`metaRow`, 
	`metaColumn`
FROM 	`ArrayBlock`
WHERE   `arrayType` = ?
ORDER BY `blockNum`
LIMIT 	?,?;


/* Feature
+-----------+--------------+------+-----+---------+----------------+
| Field     | Type         | Null | Key | Default | Extra          |
+-----------+--------------+------+-----+---------+----------------+
| id        | int(11)      |      | PRI | NULL    | auto_increment |
| arrayType | int(11)      |      | MUL | 0       |                |
| block     | smallint(6)  |      |     | 0       |                |
| x         | smallint(6)  |      |     | 0       |                |
| y         | smallint(6)  |      |     | 0       |                |
| position  | mediumint(9) |      |     | 0       |                |
| reporter  | mediumint(9) |      |     | 0       |                |
| well      | int(11)      | YES  |     | NULL    |                |
+-----------+--------------+------+-----+---------+----------------+ 

Well
+-----------------+------------------------------------+------+-----+---------+----------------+
| Field           | Type                               | Null | Key | Default | Extra          |
+-----------------+------------------------------------+------+-----+---------+----------------+
| id              | int(11)                            |      | PRI | NULL    | auto_increment |
| parent          | int(11)                            |      |     | 0       |                |
| plate           | mediumint(9)                       |      | MUL | 0       |                |
| x               | smallint(6)                        |      |     | 0       |                |
| y               | smallint(6)                        |      |     | 0       |                |
| probe           | int(11)                            |      | MUL | 0       |                |
| seqVerified     | enum('','good','bad','failed')     |      |     |         |                |
| bands           | enum('','good','missing','double') |      |     |         |                |
| bacterialGrowth | enum('','yes','no')                |      |     |         |                |
| comment         | text                               |      |     |         |                |
+-----------------+------------------------------------+------+-----+---------+----------------+*/

/* countFeatures */
SELECT count(*) FROM `Feature`;


/* selectFeaturesByArrayTypeAndBlock */
SELECT  `f`.`id`, 
	`f`.`arrayType`,
	`f`.`block`,
	`f`.`x` as fx, 
	`f`.`y` as fy, 
	`f`.`position`,
	`f`.`reporter`,
	`f`.`well`,
	`w`.`plate`,
	`w`.`x`,
	`w`.`y` 
FROM 	`Feature` f LEFT JOIN `Well` w ON `f`.`well` = `w`.`id` 
WHERE 	`arrayType` = ?
AND 	`block` = ?
ORDER BY `f`.`id`
LIMIT ?,?;

				


/* ArraySlide
+---------------+-------------+------+-----+------------+----------------+
| Field         | Type        | Null | Key | Default    | Extra          |
+---------------+-------------+------+-----+------------+----------------+
| id            | int(11)     |      | PRI | NULL       | auto_increment |
| batch         | int(11)     |      | MUL | 0          |                |
| orderNumber   | smallint(6) |      |     | 0          |                |
| name          | varchar(80) | YES  | MUL | NULL       |                |
| destroyed     | tinyint(1)  |      |     | 0          |                |
| hybridization | int(11)     | YES  | MUL | NULL       |                |
| descr         | text        |      |     |            |                |
| owner         | int(11)     |      |     | 0          |                |
| addedDate     | date        |      |     | 0000-00-00 |                |
| removed       | tinyint(1)  |      |     | 0          |                |
| gid           | int(11)     |      |     | 0          |                |
| groupAccess   | tinyint(1)  |      |     | 0          |                |
| worldAccess   | tinyint(1)  |      |     | 0          |                |
+---------------+-------------+------+-----+------------+----------------+*/

/* countArraySlides */
SELECT count(*) FROM `ArraySlide`;

/* selectArraySlides */
SELECT 	`id`, `owner`, `gid`, `groupAccess`, `worldAccess`, `name`, `descr`, `removed`, 
	`batch`, 
	`orderNumber` 
FROM `ArraySlide`
ORDER BY `id`;





/* ArrayTypePlate
+-----------+-------------+------+-----+---------+-------+
| Field     | Type        | Null | Key | Default | Extra |
+-----------+-------------+------+-----+---------+-------+
| arrayType | int(11)     |      | PRI | 0       |       |
| plate     | int(11)     |      |     | 0       |       |
| position  | smallint(6) |      | PRI | 0       |       |
+-----------+-------------+------+-----+---------+-------+*/

/* selectArrayTypePlates */
SELECT `arrayType`, 
	`plate`, 
	`position` 
FROM 	`ArrayTypePlate` 
WHERE 	`arrayType` = ?
ORDER BY `position`;




/* ArrayType
+---------------+--------------+------+-----+------------+----------------+
| Field         | Type         | Null | Key | Default    | Extra          |
+---------------+--------------+------+-----+------------+----------------+
| id            | int(11)      |      | PRI | NULL       | auto_increment |
| owner         | int(11)      |      |     | 0          |                |
| name          | varchar(80)  |      | MUL |            |                |
| platform      | varchar(255) |      |     |            |                |
| protocol      | int(11)      |      |     | 0          |                |
| descr         | text         |      |     |            |                |
| addedDate     | date         |      |     | 0000-00-00 |                |
| printed       | tinyint(1)   |      |     | 0          |                |
| printMapName  | varchar(255) |      |     |            |                |
| removed       | tinyint(1)   |      |     | 0          |                |
| gid           | int(11)      |      |     | 0          |                |
| groupAccess   | tinyint(1)   |      |     | 0          |                |
| worldAccess   | tinyint(1)   |      |     | 0          |                |
| featureLock   | smallint(6)  |      |     | 0          |                |
| featureCount  | int(11)      |      |     | 0          |                |
| blankFeatures | int(11)      |      |     | 0          |                |
+---------------+--------------+------+-----+------------+----------------+*/

/* countArrayTypes */
SELECT count(*) FROM `ArrayType`;

/* selectArrayTypes */
SELECT 	`id`, `owner`, `gid`, `groupAccess`, `worldAccess`, `name`, `descr`, `removed`, 
	`platform`, 
	`protocol`, 
	`printed`, 
	`printMapName`, 
	`featureLock`, 
	`featureCount`, 
	`blankFeatures`
FROM 	`ArrayType`
ORDER BY `id`
LIMIT	?,?;

/* countPrintmaps */
SELECT count(*) FROM `ArrayType` where `printed` > 0;

/* selectPrintmapFiles */
SELECT 	`id`, `owner`, `gid`, `groupAccess`, `worldAccess`, `printMapName`, `descr`, `removed`, 
	`addedDate`
FROM 	`ArrayType`
WHERE `printed` > 0
ORDER BY `id`
LIMIT 	?, ?;


/* Experiment
+-------------------+--------------+------+-----+------------+----------------+
| Field             | Type         | Null | Key | Default    | Extra          |
+-------------------+--------------+------+-----+------------+----------------+
| id                | int(11)      |      | PRI | NULL       | auto_increment |
| name              | varchar(80)  |      |     |            |                |
| descr             | text         |      |     |            |                |
| owner             | int(11)      |      |     | 0          |                |
| addedDate         | date         |      |     | 0000-00-00 |                |
| authors           | text         |      |     |            |                |
| affiliations      | text         |      |     |            |                |
| experimentType    | varchar(255) |      |     |            |                |
| experimentDesign  | text         |      |     |            |                |
| publication       | text         |      |     |            |                |
| abstract          | text         |      |     |            |                |
| pubMedId          | varchar(80)  |      |     |            |                |
| publicationDate   | date         |      |     | 0000-00-00 |                |
| removed           | tinyint(1)   |      |     | 3          |                |
| gid               | int(11)      |      |     | 0          |                |
| groupAccess       | tinyint(1)   |      |     | 0          |                |
| worldAccess       | tinyint(1)   |      |     | 0          |                |
| channels          | tinyint(4)   |      |     | 2          |                |
| hasMageml         | tinyint(1)   |      |     | 0          |                |
| extraColumnTables | int(11)      |      |     | 0          |                |
| diskUsage         | bigint(20)   |      |     | 0          |                |
+-------------------+--------------+------+-----+------------+----------------+*/

/* countExperiments */
SELECT count(*) FROM `Experiment`;


/* selectExperiments */
SELECT 	`id`, `owner`, `gid`, `groupAccess`, `worldAccess`, `name`, `descr`, `removed`, 
	`authors`,
	`affiliations`,
	`experimentType`,
	`experimentDesign`,
	`publication`,
	`abstract`,
	`pubMedId`,
	`publicationDate`,
	`channels`,
	`hasMageml`,
	`extraColumnTables`,
	`diskUsage`
FROM 	`Experiment`
ORDER BY `id`;




/* ExperimentRawBioAssay;
+-------------+---------+------+-----+---------+-------+
| Field       | Type    | Null | Key | Default | Extra |
+-------------+---------+------+-----+---------+-------+
| experiment  | int(11) |      | PRI | 0       |       |
| rawBioAssay | int(11) |      | PRI | 0       |       |
+-------------+---------+------+-----+---------+-------+*/

/* selectRawBioAssayByExperiment */
SELECT 	`rawBioAssay` 
FROM 	`ExperimentRawBioAssay` 
WHERE 	`experiment` = ?;



/* Extract
+----------------+-------------+------+-----+------------+----------------+
| Field          | Type        | Null | Key | Default    | Extra          |
+----------------+-------------+------+-----+------------+----------------+
| id             | int(11)     |      | PRI | NULL       | auto_increment |
| protocol       | int(11)     |      |     | 0          |                |
| extractionDate | date        |      |     | 0000-00-00 |                |
| sample         | int(11)     |      | MUL | 0          |                |
| name           | varchar(80) |      | MUL |            |                |
| descr          | text        |      |     |            |                |
| quantity       | float       |      |     | 0          |                |
| quantityLeft   | float       | YES  |     | NULL       |                |
| owner          | int(11)     |      |     | 0          |                |
| addedDate      | date        |      |     | 0000-00-00 |                |
| removed        | tinyint(1)  |      |     | 0          |                |
| gid            | int(11)     |      |     | 0          |                |
| groupAccess    | tinyint(1)  |      |     | 0          |                |
| worldAccess    | tinyint(1)  |      |     | 0          |                |
+----------------+-------------+------+-----+------------+----------------+*/

/* countExtracts */
SELECT count(*) FROM `Extract`;


/* selectExtracts */
SELECT 	`id`, `owner`, `gid`, `groupAccess`, `worldAccess`, `name`, `descr`, `removed`, 
	`extractionDate`,
	`quantity`, 
	`protocol`, 
	`sample` 
FROM 	`Extract`
ORDER BY `id`;





/* Hardware
+-------------+-------------+------+-----+------------+----------------+
| Field       | Type        | Null | Key | Default    | Extra          |
+-------------+-------------+------+-----+------------+----------------+
| id          | int(11)     |      | PRI | NULL       | auto_increment |
| name        | varchar(80) |      | MUL |            |                |
| descr       | text        |      |     |            |                |
| owner       | int(11)     |      |     | 0          |                |
| addedDate   | date        |      |     | 0000-00-00 |                |
| version     | varchar(80) |      |     |            |                |
| removed     | tinyint(1)  |      |     | 0          |                |
| gid         | int(11)     |      |     | 0          |                |
| groupAccess | tinyint(1)  |      |     | 0          |                |
| worldAccess | tinyint(1)  |      |     | 0          |                |
+-------------+-------------+------+-----+------------+----------------+*/

/* countHardware */
SELECT count(*) FROM `Hardware`;

/* selectHardware */
SELECT 	`id`, `owner`, `gid`, `groupAccess`, `worldAccess`, `name`, `descr`, `removed`, 
	`version`
FROM `Hardware`
ORDER BY `id`;



/* Hybridization
+-------------------+-------------+------+-----+------------+----------------+
| Field             | Type        | Null | Key | Default    | Extra          |
+-------------------+-------------+------+-----+------------+----------------+
| id                | int(11)     |      | PRI | NULL       | auto_increment |
| owner             | int(11)     |      |     | 0          |                |
| name              | varchar(80) |      | MUL |            |                |
| descr             | text        |      |     |            |                |
| addedDate         | date        |      |     | 0000-00-00 |                |
| hybridizationDate | date        |      |     | 0000-00-00 |                |
| protocol          | int(11)     |      |     | 0          |                |
| removed           | tinyint(1)  |      |     | 0          |                |
| gid               | int(11)     |      |     | 0          |                |
| groupAccess       | tinyint(1)  |      |     | 0          |                |
| worldAccess       | tinyint(1)  |      |     | 0          |                |
+-------------------+-------------+------+-----+------------+----------------+*/

/* countHybridizations */
SELECT count(*) FROM `Hybridization`;

/* selectHybridizations */
SELECT 	`h`.`id`, `h`.`owner`, `h`.`gid`, `h`.`groupAccess`, `h`.`worldAccess`, `h`.`name`, `h`.`descr`, `h`.`removed`, 
	`h`.`hybridizationDate`, 
	`h`.`protocol`,
	`s`.`id` as arraySlideId, 
	`s`.`hybridization` 
FROM 	`Hybridization` h LEFT JOIN `ArraySlide` s ON `h`.`id` = `s`.`hybridization`
ORDER BY `h`.`id`
LIMIT 	?,?;




/* Image
+------------------+--------------+------+-----+------------+----------------+
| Field            | Type         | Null | Key | Default    | Extra          |
+------------------+--------------+------+-----+------------+----------------+
| id               | int(11)      |      | PRI | NULL       | auto_increment |
| name             | varchar(255) |      |     |            |                |
| descr            | text         |      |     |            |                |
| owner            | int(11)      |      |     | 0          |                |
| addedDate        | date         |      |     | 0000-00-00 |                |
| imageAcquisition | int(11)      |      | MUL | 0          |                |
| channels         | tinyint(4)   |      |     | 0          |                |
| useForJpeg       | tinyint(1)   |      |     | 0          |                |
| fileSize         | int(11)      |      |     | 0          |                |
| removed          | tinyint(1)   |      |     | 0          |                |
+------------------+--------------+------+-----+------------+----------------+*/

/* countImages */
SELECT count(*) FROM `Image`;

/* selectImages */
SELECT 	`id`, `owner`, 0 as gid, 0 as groupAccess, 0 as worldAccess, `name`, `descr`, `removed`, `imageAcquisition`, `channels`, `useForJpeg`, `fileSize` 
FROM `Image`
ORDER BY `id`
LIMIT ?,?;



/* selectImageFiles */
SELECT 	`id`, `owner`, 0 as gid, 0 as groupAccess, 0 as worldAccess, `name`, `descr`, `removed`, `fileSize`, `addedDate`
FROM `Image`
ORDER BY `id`
LIMIT ?,?;


/* Label
+-------------+-------------+------+-----+------------+----------------+
| Field       | Type        | Null | Key | Default    | Extra          |
+-------------+-------------+------+-----+------------+----------------+
| id          | int(11)     |      | PRI | NULL       | auto_increment |
| name        | varchar(80) |      | MUL |            |                |
| descr       | text        |      |     |            |                |
| owner       | int(11)     |      |     | 0          |                |
| addedDate   | date        |      |     | 0000-00-00 |                |
| removed     | tinyint(1)  |      |     | 0          |                |
| gid         | int(11)     |      |     | 0          |                |
| groupAccess | tinyint(1)  |      |     | 0          |                |
| worldAccess | tinyint(1)  |      |     | 0          |                |
+-------------+-------------+------+-----+------------+----------------+*/

/* countLabels */
SELECT count(*) FROM `Label`;

/* selectLabels */
SELECT	`id`, `owner`, `gid`, `groupAccess`, `worldAccess`, `name`, `descr`, `removed`
FROM 	`Label`
ORDER BY `id`
LIMIT   ?,?;



/* LabeledExtract
+--------------+-------------+------+-----+------------+----------------+
| Field        | Type        | Null | Key | Default    | Extra          |
+--------------+-------------+------+-----+------------+----------------+
| id           | int(11)     |      | PRI | NULL       | auto_increment |
| owner        | int(11)     |      |     | 0          |                |
| name         | varchar(80) |      | MUL |            |                |
| descr        | text        |      |     |            |                |
| addedDate    | date        |      |     | 0000-00-00 |                |
| extract      | int(11)     |      | MUL | 0          |                |
| protocol     | int(11)     |      |     | 0          |                |
| labelingDate | date        |      |     | 0000-00-00 |                |
| quantity     | float       |      |     | 0          |                |
| quantityLeft | float       | YES  |     | NULL       |                |
| removed      | tinyint(1)  |      |     | 0          |                |
| gid          | int(11)     |      |     | 0          |                |
| groupAccess  | tinyint(1)  |      |     | 0          |                |
| worldAccess  | tinyint(1)  |      |     | 0          |                |
| label        | int(11)     |      |     | 0          |                |
+--------------+-------------+------+-----+------------+----------------+*/

/* countLabeledExtracts */
SELECT count(*) FROM `LabeledExtract`;


/* selectLabeledExtracts */
SELECT	`id`, `owner`, `gid`, `groupAccess`, `worldAccess`, `name`, `descr`, `removed`,
	`labelingDate`, 
	`quantity`, 
	`protocol`, 
	`extract`, 
	`label`
FROM 	`LabeledExtract` 
ORDER BY `id`
LIMIT   ?,?;

/* selectLabeledExtractsByHybridization */
SELECT	`labeled`, `quantity`
FROM 	`HybridizedLabeled` 
WHERE hybridization = ?
ORDER BY `channel`;



/* PlateParent
+----------+------------+------+-----+---------+-------+
| Field    | Type       | Null | Key | Default | Extra |
+----------+------------+------+-----+---------+-------+
| parent   | int(11)    |      | MUL | 0       |       |
| plate    | int(11)    |      | MUL | 0       |       |
| position | tinyint(4) |      |     | 0       |       |
+----------+------------+------+-----+---------+-------+*/

/* countDistinctPlateParents */
SELECT count( distinct(`plate`) ) FROM `PlateParent`;


/* selectPlateParents */
SELECT `plate`, `parent`, `position` FROM `PlateParent`;






/* Plate
+-------------+--------------+------+-----+------------+----------------+
| Field       | Type         | Null | Key | Default    | Extra          |
+-------------+--------------+------+-----+------------+----------------+
| id          | int(11)      |      | PRI | NULL       | auto_increment |
| plateType   | int(11)      |      |     | 0          |                |
| name        | varchar(255) | YES  | MUL | NULL       |                |
| descr       | text         |      |     |            |                |
| owner       | int(11)      |      |     | 0          |                |
| addedDate   | date         |      |     | 0000-00-00 |                |
| destroyed   | tinyint(1)   |      |     | 0          |                |
| barcode     | varchar(255) | YES  | MUL | NULL       |                |
| wizzzard    | int(11)      |      |     | 0          |                |
| removed     | tinyint(1)   |      |     | 3          |                |
| gid         | int(11)      |      |     | 0          |                |
| groupAccess | tinyint(1)   |      |     | 0          |                |
| worldAccess | tinyint(1)   |      |     | 0          |                |
| wellMapping | smallint(6)  | YES  |     | NULL       |                |
+-------------+--------------+------+-----+------------+----------------+*/

/* selectMappedPlates */
SELECT 	`p`.`id`, `p`.`owner`, `p`.`gid`, `p`.`groupAccess`, `p`.`worldAccess`, `p`.`name`, `p`.`descr`, `p`.`removed`, 
	`p`.`plateType`, 
	`p`.`destroyed`, 
	`p`.`barcode`, 
	`p`.`wizzzard`, 
	`pp`.`parent`, 
	`pp`.`position`, 
	`pt`.`wells`
FROM 	`Plate` p LEFT JOIN `PlateParent` pp ON `pp`.`plate` = `p`.`id`
	LEFT JOIN `PlateType` pt ON `p`.`plateType` = `pt`.`id`
WHERE 	`pp`.`plate` IS not NULL 
GROUP BY `pp`.`plate`
ORDER BY `p`.`id`
LIMIT ?,?;




/* News
+-----------+--------------+------+-----+---------------------+----------------+
| Field     | Type         | Null | Key | Default             | Extra          |
+-----------+--------------+------+-----+---------------------+----------------+
| id        | int(11)      |      | PRI | NULL                | auto_increment |
| name      | varchar(255) |      |     |                     |                |
| descr     | text         |      |     |                     |                |
| owner     | int(11)      |      |     | 0                   |                |
| addedDate | datetime     |      | MUL | 0000-00-00 00:00:00 |                |
| removed   | tinyint(1)   |      |     | 0                   |                |
+-----------+--------------+------+-----+---------------------+----------------+*/

/* countNews */
SELECT count(*) FROM `News`;

/* selectNews */
SELECT `id`, `name`, `descr`, `addedDate`, `removed` 
FROM `News`
ORDER BY `id`;




/* PlateEvent
+-----------+---------+------+-----+------------+-------+
| Field     | Type    | Null | Key | Default    | Extra |
+-----------+---------+------+-----+------------+-------+
| plate     | int(11) |      | PRI | 0          |       |
| etype     | int(11) |      | PRI | 0          |       |
| eventDate | date    |      | MUL | 0000-00-00 |       |
| protocol  | int(11) |      |     | 0          |       |
+-----------+---------+------+-----+------------+-------+*/

/* countPlateEvents */
SELECT count(*) FROM `PlateEvent`;

/* selectPlateEvents */
SELECT `plate`, `etype`, `eventDate`, `protocol` 
FROM `PlateEvent`
ORDER BY `plate`, `etype`;







/* PlateEventType
+--------------+-------------+------+-----+------------+----------------+
| Field        | Type        | Null | Key | Default    | Extra          |
+--------------+-------------+------+-----+------------+----------------+
| id           | int(11)     |      | PRI | NULL       | auto_increment |
| name         | varchar(80) |      |     |            |                |
| plateType    | int(11)     |      | MUL | 0          |                |
| protocolType | int(11)     |      |     | 0          |                |
| descr        | text        |      |     |            |                |
| addedDate    | date        |      |     | 0000-00-00 |                |
| owner        | int(11)     |      |     | 0          |                |
| removed      | tinyint(1)  |      |     | 0          |                |
+--------------+-------------+------+-----+------------+----------------+*/

/* countPlateEventTypes */
SELECT count(*) FROM `PlateEventType`;


/* selectPlateEventTypes */
SELECT `id`, `name`, `plateType`, `protocolType`, `descr`, `removed` 
FROM `PlateEventType`
ORDER BY `id`;




/* PlateType
+----------------+-------------+------+-----+------------+----------------+
| Field          | Type        | Null | Key | Default    | Extra          |
+----------------+-------------+------+-----+------------+----------------+
| id             | int(11)     |      | PRI | NULL       | auto_increment |
| name           | varchar(80) |      | MUL |            |                |
| descr          | text        |      |     |            |                |
| owner          | int(11)     |      |     | 0          |                |
| addedDate      | date        |      |     | 0000-00-00 |                |
| wells          | smallint(6) |      |     | 0          |                |
| hasGrowth      | tinyint(1)  |      |     | 0          |                |
| hasSeqVerified | tinyint(1)  |      |     | 0          |                |
| hasBands       | tinyint(1)  |      |     | 0          |                |
| hasComment     | tinyint(1)  |      |     | 0          |                |
| namePrefix     | varchar(40) |      |     |            |                |
| parentSuffix   | tinyint(1)  |      |     | 0          |                |
| removed        | tinyint(1)  |      |     | 0          |                |
| gid            | int(11)     |      |     | 0          |                |
| groupAccess    | tinyint(1)  |      |     | 0          |                |
| worldAccess    | tinyint(1)  |      |     | 0          |                |
+----------------+-------------+------+-----+------------+----------------+*/

/* countPlateTypes */
SELECT count(*) FROM `PlateType`;


/* selectPlateTypes */
SELECT	`id`, `owner`, `gid`, `groupAccess`, `worldAccess`, `name`, `descr`, `removed`,
	`wells`, 
	`hasGrowth`, 
	`hasSeqVerified`, 
	`hasBands`, 
	`hasComment`, 
	`namePrefix`, 
	`parentSuffix`
FROM 	`PlateType`
ORDER BY `id`
LIMIT   ?,?;





/* Protocol
+--------------+--------------+------+-----+------------+----------------+
| Field        | Type         | Null | Key | Default    | Extra          |
+--------------+--------------+------+-----+------------+----------------+
| id           | int(11)      |      | PRI | NULL       | auto_increment |
| protocolType | int(11)      |      | MUL | 0          |                |
| name         | varchar(80)  |      |     |            |                |
| descr        | text         |      |     |            |                |
| owner        | int(11)      |      |     | 0          |                |
| addedDate    | date         |      |     | 0000-00-00 |                |
| removed      | tinyint(1)   |      |     | 0          |                |
| gid          | int(11)      |      |     | 0          |                |
| groupAccess  | tinyint(1)   |      |     | 0          |                |
| worldAccess  | tinyint(1)   |      |     | 0          |                |
| fileSize     | int(11)      |      |     | 0          |                |
| filename     | varchar(255) | YES  |     | NULL       |                |
+--------------+--------------+------+-----+------------+----------------+*/

/* countProtocols */
SELECT count(*) FROM `Protocol`;

/* selectProtocols */
SELECT	`id`, `owner`, `gid`, `groupAccess`, `worldAccess`, `name`, `descr`, `removed`,
	`protocolType`, 
	`addedDate`
FROM 	`Protocol`
ORDER BY `id`
LIMIT	?,?;

/* selectProtocolFiles */
SELECT	`id`, `owner`, `gid`, `groupAccess`, `worldAccess`, `name`, `descr`, `removed`,
	`fileSize`, 
	`addedDate`,
	`filename`
FROM 	`Protocol`
ORDER BY `id`
LIMIT	?,?;





/* ProtocolType;
+-------+-------------+------+-----+---------+----------------+
| Field | Type        | Null | Key | Default | Extra          |
+-------+-------------+------+-----+---------+----------------+
| id    | int(11)     |      | PRI | NULL    | auto_increment |
| name  | varchar(80) |      | UNI |         |                |
+-------+-------------+------+-----+---------+----------------+*/

/* countProtocolTypes */
SELECT count(*) FROM `ProtocolType`;

/* selectProtocolTypes */
SELECT `id`, `name` 
FROM `ProtocolType` 
ORDER BY `id`
LIMIT ?,?;





/*  RawBioAssayData
+-------------+--------------+------+-----+---------+-------+
| Field       | Type         | Null | Key | Default | Extra |
+-------------+--------------+------+-----+---------+-------+
| rawBioAssay | mediumint(9) |      | PRI | 0       |       |
| position    | mediumint(9) |      | PRI | 0       |       |
| element     | mediumint(9) |      |     | 0       |       |
| reporter    | mediumint(9) |      |     | 0       |       |
| block       | smallint(6)  | YES  |     | NULL    |       |
| numCol      | tinyint(4)   | YES  |     | NULL    |       |
| numRow      | tinyint(4)   | YES  |     | NULL    |       |
| x           | float        |      |     | 0       |       |
| y           | float        |      |     | 0       |       |
| dia         | float        | YES  |     | NULL    |       |
| FCh1Median  | float        | YES  |     | NULL    |       |
| FCh1Mean    | float        | YES  |     | NULL    |       |
| FCh1SD      | float        | YES  |     | NULL    |       |
| BCh1Median  | float        | YES  |     | NULL    |       |
| BCh1Mean    | float        | YES  |     | NULL    |       |
| BCh1SD      | float        | YES  |     | NULL    |       |
| percCh1SD1  | tinyint(4)   | YES  |     | NULL    |       |
| percCh1SD2  | tinyint(4)   | YES  |     | NULL    |       |
| percCh1Sat  | tinyint(4)   | YES  |     | NULL    |       |
| FCh2Median  | float        | YES  |     | NULL    |       |
| FCh2Mean    | float        | YES  |     | NULL    |       |
| FCh2SD      | float        | YES  |     | NULL    |       |
| BCh2Median  | float        | YES  |     | NULL    |       |
| BCh2Mean    | float        | YES  |     | NULL    |       |
| BCh2SD      | float        | YES  |     | NULL    |       |
| percCh2SD1  | tinyint(4)   | YES  |     | NULL    |       |
| percCh2SD2  | tinyint(4)   | YES  |     | NULL    |       |
| percCh2Sat  | tinyint(4)   | YES  |     | NULL    |       |
| ratiosSD    | float        | YES  |     | NULL    |       |
| rgnRatio    | float        | YES  |     | NULL    |       |
| rgnR2       | float        | YES  |     | NULL    |       |
| FPixels     | smallint(6)  | YES  |     | NULL    |       |
| BPixels     | smallint(6)  | YES  |     | NULL    |       |
| flags       | tinyint(4)   | YES  |     | NULL    |       |
| MValue      | float        | YES  |     | NULL    |       |
| CV          | float        | YES  |     | NULL    |       |
+-------------+--------------+------+-----+---------+-------+*/

/* countRawBioAssayData */
SELECT count(*) FROM `RawBioAssayData`;


/* selectRawBioAssayData */
SELECT `element`, `reporter`, `block`, `numCol`, `numRow`, `x`, `y`,
	`dia`,
	`FCh1Median`,
	`FCh1Mean`,
	`FCh1SD`,
	`BCh1Median`,
	`BCh1Mean`,
	`BCh1SD`,
	`FCh2Median`,
	`FCh2Mean`,
	`FCh2SD`,
	`BCh2Median`,
	`BCh2Mean`,
	`BCh2SD`,
	`ratiosSD`,
	`rgnRatio`,
	`rgnR2`,
	`MValue`,
	`CV`,
	`percCh1SD1`,
	`percCh1SD2`,
	`percCh1Sat`,
	`percCh2SD1`,
	`percCh2SD2`,
	`percCh2Sat`,
	`FPixels`,
	`BPixels`,
	`flags` 
FROM	`RawBioAssayData`
WHERE 	`rawBioAssay` = ?;


/* selectMinimumRawBioAssayData */
SELECT `element`, `reporter`, `block`, `numCol`, `numRow`, `x`, `y`
FROM	`RawBioAssayData`
WHERE 	`rawBioAssay` = ?;



/* RawBioAssay
+------------------+--------------+------+-----+------------+----------------+
| Field            | Type         | Null | Key | Default    | Extra          |
+------------------+--------------+------+-----+------------+----------------+
| id               | int(11)      |      | PRI | NULL       | auto_increment |
| name             | varchar(80)  |      |     |            |                |
| descr            | text         |      |     |            |                |
| owner            | int(11)      |      |     | 0          |                |
| addedDate        | date         |      |     | 0000-00-00 |                |
| imageAcquisition | int(11)      |      | MUL | 0          |                |
| featureDate      | date         |      |     | 0000-00-00 |                |
| featureSoftware  | int(11)      |      |     | 0          |                |
| filename         | varchar(255) |      |     |            |                |
| spots            | mediumint(9) |      |     | 0          |                |
| hasSpotImages    | tinyint(1)   |      |     | 0          |                |
| spotImagePixels  | smallint(6)  |      |     | 15         |                |
| spotImageOffsetX | float        |      |     | 0          |                |
| spotImageOffsetY | float        |      |     | 0          |                |
| spotImageScale   | float        |      |     | 1          |                |
| wizzzard         | int(11)      |      |     | 0          |                |
| removed          | tinyint(1)   |      |     | 3          |                |
| gid              | int(11)      |      |     | 0          |                |
| groupAccess      | tinyint(1)   |      |     | 0          |                |
| worldAccess      | tinyint(1)   |      |     | 0          |                |
| arrayType        | int(11)      | YES  |     | NULL       |                |
| positionMode     | tinyint(4)   |      |     | 0          |                |
| diskUsage        | bigint(20)   |      |     | 0          |                |
+------------------+--------------+------+-----+------------+----------------+*/

/* countRawBioAssays */
SELECT count(*) FROM `RawBioAssay`;

/* selectRawBioAssays */
SELECT 	`id`, `owner`, `gid`, `groupAccess`, `worldAccess`, `name`, `descr`, `removed`, 
	`imageAcquisition`, 
	`featureDate`, 
	`featureSoftware`, 
	`filename`, 
	`spots`,
	`hasSpotImages`, 
	`spotImagePixels`, 
	`spotImageOffsetX`, 
	`spotImageOffsetY`, 
	`spotImageScale`, 
	`wizzzard`, 
	`arrayType`, 
	`positionMode`, 
	`fileHeader`
FROM 	`RawBioAssay` LEFT JOIN `RawBioAssayHeader` ON 	`id` = rawBioAssay
ORDER BY `id`
LIMIT 	?, ?;

/* getCh1SampleForRawBioAssay */
SELECT s.`id` FROM `Sample` s
INNER JOIN `Extract` e ON e.`sample` = s.`id`
INNER JOIN `LabeledExtract` le ON le.`extract` = e.`id`
INNER JOIN `HybridizedLabeled` hl ON hl.`labeled` = le.`id` AND hl.`channel` = 1
INNER JOIN `ImageAcquisition` ia ON ia.`hybridization` =  hl.`hybridization`
INNER JOIN `RawBioAssay` rba ON rba.`imageAcquisition` = ia.`id`
WHERE rba.`id` = ?;

/* selectRawBioAssaysWithSpotData */
SELECT 	`id`, `owner`, `gid`, `groupAccess`, `worldAccess`, `name`, `descr`, `removed`, 
	`imageAcquisition`, 
	`featureDate`, 
	`featureSoftware`, 
	`filename`, 
	`spots`,
	`hasSpotImages`, 
	`spotImagePixels`, 
	`spotImageOffsetX`, 
	`spotImageOffsetY`, 
	`spotImageScale`, 
	`wizzzard`, 
	`arrayType`, 
	`positionMode`
FROM 	`RawBioAssay`
ORDER BY `id`
LIMIT   ?,?;


/* selectRawBioAssayFiles */
SELECT 	`id`, `owner`, `gid`, `groupAccess`, `worldAccess`, `name`, `descr`, `removed`, 
	`addedDate`
FROM 	`RawBioAssay`
ORDER BY `id`
LIMIT 	?, ?;


/* Reporter
+---------------+--------------+------+-----+---------------------+----------------+
| Field         | Type         | Null | Key | Default             | Extra          |
+---------------+--------------+------+-----+---------------------+----------------+
| id            | mediumint(9) |      | PRI | NULL                | auto_increment |
| reporterId    | varchar(255) |      | UNI |                     |                |
| species       | varchar(255) |      |     |                     |                |
| clusterId     | int(11)      |      |     | 0                   |                |
| geneName      | varchar(255) |      | MUL |                     |                |
| geneSymbol    | varchar(255) |      |     |                     |                |
| lastUpdate    | datetime     |      |     | 0000-00-00 00:00:00 |                |
| length        | int(11)      | YES  |     | 0                   |                |
| sequence      | text         | YES  |     | NULL                |                |
| vector        | text         | YES  |     | NULL                |                |
| tissue        | text         | YES  |     | NULL                |                |
| library       | text         | YES  |     | NULL                |                |
| accession     | varchar(255) | YES  |     | NULL                |                |
| nid           | varchar(255) | YES  |     | NULL                |                |
| chromosome    | varchar(255) | YES  |     | NULL                |                |
| cytoBand      | varchar(255) | YES  |     | NULL                |                |
| markers       | varchar(255) | YES  |     | NULL                |                |
| antibiotics   | varchar(255) | YES  |     | NULL                |                |
| locusLink     | int(11)      | YES  |     | 0                   |                |
| omim          | int(11)      | YES  |     | 0                   |                |
| startPosition | int(11)      | YES  |     | 0                   |                |
| endPosition   | int(11)      | YES  |     | 0                   |                |
+---------------+--------------+------+-----+---------------------+----------------+*/

/* countReporters */
SELECT count(*) FROM `Reporter`;

/* selectReporters */
SELECT `id`, 
	`reporterId`, 
	`geneName`, 
	`geneSymbol`, 
	`species`, 
	`clusterId`, 
	`accession`, 
	`nid`, 
	`chromosome`, 
	`cytoband`, 
	`markers`, 
	`antibiotics`, 
	`locuslink`, 
	`omim`, 
	`sequence`, 
	`vector`, 
	`tissue`, 
	`library`, 
	`length`
FROM 	`Reporter`
ORDER BY `id`
LIMIT   ?,?;

/* selectMinimumReporters */
SELECT `id`, `reporterId`, `geneName`, `geneSymbol`
FROM `Reporter` 
ORDER BY `id` 
LIMIT ?,?;






/* SampleTissue
+-----------+-------------+------+-----+------------+----------------+
| Field     | Type        | Null | Key | Default    | Extra          |
+-----------+-------------+------+-----+------------+----------------+
| id        | int(11)     |      | PRI | NULL       | auto_increment |
| parent    | int(11)     |      | MUL | 0          |                |
| name      | varchar(80) |      |     |            |                |
| descr     | text        |      |     |            |                |
| owner     | int(11)     |      |     | 0          |                |
| addedDate | date        |      |     | 0000-00-00 |                |
| removed   | tinyint(1)  |      |     | 0          |                |
+-----------+-------------+------+-----+------------+----------------+*/

/* countSampleTissues */
SELECT count(*) FROM `SampleTissue`;


/* selectSampleTissues */
SELECT `id`, `parent`, `name` 
FROM `SampleTissue`
ORDER BY `id`
LIMIT ?,?;




/* Sample
+-------------+-------------+------+-----+------------+----------------+
| Field       | Type        | Null | Key | Default    | Extra          |
+-------------+-------------+------+-----+------------+----------------+
| id          | int(11)     |      | PRI | NULL       | auto_increment |
| name        | varchar(80) |      | MUL |            |                |
| descr       | text        |      |     |            |                |
| tissue      | int(11)     |      |     | 0          |                |
| owner       | int(11)     |      |     | 0          |                |
| addedDate   | date        |      |     | 0000-00-00 |                |
| sampleDate  | date        |      |     | 0000-00-00 |                |
| removed     | tinyint(1)  |      |     | 0          |                |
| gid         | int(11)     |      |     | 0          |                |
| groupAccess | tinyint(1)  |      |     | 0          |                |
| worldAccess | tinyint(1)  |      |     | 0          |                |
+-------------+-------------+------+-----+------------+----------------+*/

/* countSamples */
SELECT count(*) FROM `Sample`;


/* selectSampleQuantities */
SELECT `s`.`id`, sum(`e`.`quantity`) 
FROM `Sample` s, `Extract` e 
WHERE `s`.`id` = `e`.`sample` 
GROUP BY `e`.`sample`;


/* selectSamples */
SELECT 	`id`, `owner`, `gid`, `groupAccess`, `worldAccess`, `name`, `descr`, `removed`, 
	`sampleDate`, 0 as quantity, 0 as protocol, `tissue` 
FROM 	`Sample`
ORDER BY `id`
LIMIT	?,?;




/* ImageAcquisition
+---------------+-------------+------+-----+------------+----------------+
| Field         | Type        | Null | Key | Default    | Extra          |
+---------------+-------------+------+-----+------------+----------------+
| id            | int(11)     |      | PRI | NULL       | auto_increment |
| name          | varchar(80) |      |     |            |                |
| descr         | text        |      |     |            |                |
| owner         | int(11)     |      |     | 0          |                |
| addedDate     | date        |      |     | 0000-00-00 |                |
| hybridization | int(11)     |      | MUL | 0          |                |
| scanDate      | date        |      |     | 0000-00-00 |                |
| scanner       | int(11)     |      |     | 0          |                |
| removed       | tinyint(1)  |      |     | 0          |                |
| gid           | int(11)     |      |     | 0          |                |
| groupAccess   | tinyint(1)  |      |     | 0          |                |
| worldAccess   | tinyint(1)  |      |     | 0          |                |
| diskUsage     | bigint(20)  |      |     | 0          |                |
+---------------+-------------+------+-----+------------+----------------+*/

/* countScans */
SELECT count(*) FROM `ImageAcquisition`;

/* selectScans */
SELECT 	`id`, `owner`, `gid`, `groupAccess`, `worldAccess`, `name`, `descr`, `removed`, 
	`hybridization`, 
	`scanDate`, 
	`scanner` 
FROM 	`ImageAcquisition`
ORDER BY `id`
LIMIT 	?,?;




/* Software
+-------------+-------------+------+-----+------------+----------------+
| Field       | Type        | Null | Key | Default    | Extra          |
+-------------+-------------+------+-----+------------+----------------+
| id          | int(11)     |      | PRI | NULL       | auto_increment |
| name        | varchar(80) |      | MUL |            |                |
| descr       | text        |      |     |            |                |
| owner       | int(11)     |      |     | 0          |                |
| addedDate   | date        |      |     | 0000-00-00 |                |
| version     | varchar(80) |      |     |            |                |
| removed     | tinyint(1)  |      |     | 0          |                |
| gid         | int(11)     |      |     | 0          |                |
| groupAccess | tinyint(1)  |      |     | 0          |                |
| worldAccess | tinyint(1)  |      |     | 0          |                |
+-------------+-------------+------+-----+------------+----------------+*/

/* countSoftware */
SELECT count(*) FROM `Software`;


/* selectSoftware */
SELECT 	`id`, `owner`, `gid`, `groupAccess`, `worldAccess`, `name`, `descr`, `removed`, 
	`version`
FROM	`Software`
ORDER BY `id`
LIMIT	?,?;



/* Plate
+-------------+--------------+------+-----+------------+----------------+
| Field       | Type         | Null | Key | Default    | Extra          |
+-------------+--------------+------+-----+------------+----------------+
| id          | int(11)      |      | PRI | NULL       | auto_increment |
| plateType   | int(11)      |      |     | 0          |                |
| name        | varchar(255) | YES  | MUL | NULL       |                |
| descr       | text         |      |     |            |                |
| owner       | int(11)      |      |     | 0          |                |
| addedDate   | date         |      |     | 0000-00-00 |                |
| destroyed   | tinyint(1)   |      |     | 0          |                |
| barcode     | varchar(255) | YES  | MUL | NULL       |                |
| wizzzard    | int(11)      |      |     | 0          |                |
| removed     | tinyint(1)   |      |     | 3          |                |
| gid         | int(11)      |      |     | 0          |                |
| groupAccess | tinyint(1)   |      |     | 0          |                |
| worldAccess | tinyint(1)   |      |     | 0          |                |
| wellMapping | smallint(6)  | YES  |     | NULL       |                |
+-------------+--------------+------+-----+------------+----------------+*/

/* countPlates */
SELECT count(*) FROM `Plate`;

/* countUnmappedPlates */
SELECT count(*) FROM `Plate` p LEFT JOIN `PlateParent` pp ON `pp`.`plate` = `p`.`id` WHERE `pp`.`plate` IS NULL;

/* selectUnmappedPlates */
SELECT 	`p`.`id`, `p`.`owner`, `p`.`gid`, `p`.`groupAccess`, `p`.`worldAccess`, `p`.`name`, `p`.`descr`, `p`.`removed`, 
	`p`.`plateType`, 
	`p`.`destroyed`, 
	`p`.`barcode`, 
	`p`.`wizzzard` 
FROM 	`Plate` p LEFT JOIN `PlateParent` pp ON `pp`.`plate` = `p`.`id` WHERE `pp`.`plate` IS NULL
ORDER BY `p`.`id`
LIMIT	?,?;


/* Probe
+----------+--------------+------+-----+---------+----------------+
| Field    | Type         | Null | Key | Default | Extra          |
+----------+--------------+------+-----+---------+----------------+
| id       | int(11)      |      | PRI | NULL    | auto_increment |
| reporter | mediumint(9) |      |     | 0       |                |
+----------+--------------+------+-----+---------+----------------+*/

/* selectWellAndProbesByPlateId */
SELECT 	`w`.`id`, `w`.`x`, `w`.`y`, `p`.`reporter`, `w`.`seqVerified`, `w`.`bands`, `w`.`bacterialGrowth`, `w`.`comment` 
FROM   	`Well` w, `Probe` p 
WHERE 	`w`.`probe` = `p`.`id` 
AND 	`plate` = ?
ORDER BY `y`;



/* Upload
+-------------+--------------+------+-----+---------------------+----------------+
| Field       | Type         | Null | Key | Default             | Extra          |
+-------------+--------------+------+-----+---------------------+----------------+
| id          | int(11)      |      | PRI | NULL                | auto_increment |
| owner       | int(11)      |      | MUL | 0                   |                |
| name        | varchar(255) | YES  |     | NULL                |                |
| fileSize    | int(11)      |      |     | 0                   |                |
| descr       | text         |      |     |                     |                |
| addedDate   | datetime     |      |     | 0000-00-00 00:00:00 |                |
| mimeType    | varchar(100) |      |     |                     |                |
| removed     | tinyint(1)   |      |     | 3                   |                |
| gid         | int(11)      |      |     | 0                   |                |
| groupAccess | tinyint(1)   |      |     | 0                   |                |
| worldAccess | tinyint(1)   |      |     | 0                   |                |
+-------------+--------------+------+-----+---------------------+----------------+*/

/* countUploads */
SELECT count(*) FROM `Upload` WHERE `removed` = 0;

/* selectUploads */
SELECT 	`id`, `owner`, `gid`, `groupAccess`, `worldAccess`, `name`, `descr`, `removed`, 
	`fileSize`, 
	`addedDate`, 
	`mimeType`  
FROM 	`Upload` 
WHERE 	`removed` = 0 
ORDER BY `id`
LIMIT   ?,?;




/* Wizzzard
+----------------+-------------+------+-----+------------+----------------+
| Field          | Type        | Null | Key | Default    | Extra          |
+----------------+-------------+------+-----+------------+----------------+
| id             | int(11)     |      | PRI | NULL       | auto_increment |
| owner          | int(11)     |      |     | 0          |                |
| formatType     | varchar(40) |      | MUL |            |                |
| name           | varchar(80) |      |     |            |                |
| minCols        | smallint(6) |      |     | 0          |                |
| maxCols        | smallint(6) |      |     | 0          |                |
| dataHeader     | text        |      |     |            |                |
| typeHeader     | text        |      |     |            |                |
| typeHeaderLine | int(11)     |      |     | 0          |                |
| mapping        | mediumtext  |      |     |            |                |
| descr          | text        |      |     |            |                |
| addedDate      | date        |      |     | 0000-00-00 |                |
| removed        | tinyint(1)  |      |     | 0          |                |
| gid            | int(11)     |      |     | 0          |                |
| groupAccess    | tinyint(1)  |      |     | 0          |                |
| worldAccess    | tinyint(1)  |      |     | 0          |                |
| dataFooter     | text        | YES  |     | NULL       |                |
| fieldSeparator | varchar(10) |      |     |            |                |
| maxHeaderLine  | int(11)     |      |     | 120        |                |
+----------------+-------------+------+-----+------------+----------------+*/

/* countWizzzards */
SELECT count(*) FROM `Wizzzard`;


/* selectWizzzards */
SELECT 	`id`, `owner`, `gid`, `groupAccess`, `worldAccess`, `name`, `descr`, `removed`, 
	`formatType`,
	`minCols`,
	`maxCols`,
	`dataHeader`,
	`typeHeader`,
	`typeHeaderLine`,
	`mapping`,
	`dataFooter`,
	`fieldSeparator`,
	`maxHeaderLine`
FROM 	`Wizzzard`
ORDER BY `id`
LIMIT   ?,?;

/* countPlugins */
SELECT count(*) FROM `Program`;

/* selectPlugins */
SELECT 	`id`, `owner`, `gid`, `groupAccess`, `worldAccess`, `name`, `descr`, `removed`, 
	`execName`,
	`usedColumns`,
	`usedFields`,
	`geneAverages`,
	`serialFormat`,
	`url`,
	`minChannels`,
	`maxChannels`,
	`leaveStdin`,
	`leaveStdout`,
	`uniqueName`,
	`versionNumber`,
	`estimatedTime`,
	`defaultMaxRam`
FROM 	`Program`
ORDER BY `id`
LIMIT   ?,?;

/* selectPluginParameters */
SELECT `position`,
	`name`,
	`commonName`,
	`valueType`,
	`options`,
	`defaultValue`,
	`enumOptions`, 
	`removed`
FROM `ProgramParameter`
WHERE `program` = ?
ORDER BY `position`;
