<%-- $Id: edit_formula.jsp 4476 2008-09-05 15:14:42Z jari $
	------------------------------------------------------------------
	Copyright (C) 2006 Jari Hakkinen, Nicklas Nordborg, Martin Svensson
	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 59 Temple Place - Suite 330,
	Boston, MA  02111-1307, USA.
	------------------------------------------------------------------


	@author Nicklas
	@version 2.0
--%>
<%@ page session="false"
	import="net.sf.basedb.core.SessionControl"
	import="net.sf.basedb.core.DbControl"
	import="net.sf.basedb.core.Item"
	import="net.sf.basedb.core.ItemContext"
	import="net.sf.basedb.core.Permission"
	import="net.sf.basedb.core.Formula"
	import="net.sf.basedb.core.Coloring"
	import="net.sf.basedb.core.RawDataType"
	import="net.sf.basedb.core.RawDataTypes"
	import="net.sf.basedb.core.RawDataProperty"
	import="net.sf.basedb.core.Project"
	import="net.sf.basedb.core.PermissionDeniedException"
	import="net.sf.basedb.util.Values"
	import="net.sf.basedb.clients.web.Base"
	import="net.sf.basedb.clients.web.util.HTML"
	import="java.util.List"
%>
<%@ taglib prefix="base" uri="/WEB-INF/base.tld" %>
<%@ taglib prefix="t" uri="/WEB-INF/tab.tld" %>
<%
final Item itemType = Item.FORMULA;
final SessionControl sc = Base.getExistingSessionControl(pageContext, true);
final ItemContext cc = Base.getAndSetCurrentContext(sc, itemType, null, null);
final int itemId = cc.getId();
final String ID = sc.getId();
final float scale = Base.getScale(sc);
final DbControl dc = sc.newDbControl();
try
{
	String title = null;
	Formula formula = null;
	Formula.Type currentType = null;
	Formula.Parser currentParser = null;
	Formula.AverageMethod currentAverageMethod = null;
	RawDataType currentRawDataType = null;
	RawDataType defaultRawDataType = null;
	List<String> expressions = null;
	Coloring coloring = null;

	int activeProjectId = sc.getActiveProjectId();
	if (activeProjectId > 0)
	{
		Project activeProject =	Project.getById(dc, activeProjectId);
		defaultRawDataType = activeProject.getDefaultRawDataType();
	}	
	if (itemId == 0)
	{
		title = "Create formula";
		cc.removeObject("item");
		String recentType = cc.getRecent("FormulaType", 0);
		String filterType = cc.getPropertyValue("type");
		if (filterType != null) currentType =  Formula.Type.fromValue(Values.getInt(filterType));
		if (currentType == null && recentType != null) currentType = Formula.Type.valueOf(recentType);
		if (currentType == null) currentType = Formula.Type.COLUMN_EXPRESSION;
		currentParser = Formula.Parser.fromValue(Values.getInt(cc.getPropertyValue("parser"), 
			Formula.Parser.JEP.getValue()));
		currentAverageMethod = Formula.AverageMethod.fromValue(Values.getInt(cc.getPropertyValue("averageMethod"),
			Formula.AverageMethod.ARITHMETIC_MEAN.getValue()));
		currentRawDataType = RawDataTypes.getRawDataType(cc.getPropertyValue("rawDataType"));
		if (currentRawDataType == null)
		{
			currentRawDataType = RawDataTypes.getRawDataType(cc.getRecent("RawDataType", 0));
		}
		coloring = new Coloring();
		coloring.setUsingColors(Values.getBoolean(cc.getPropertyValue("coloring.usingColors")));
		coloring.setLogarithmic(Values.getBoolean(cc.getPropertyValue("coloring.logarithmic")));
		coloring.setMinValue(Values.getFloat(cc.getPropertyValue("coloring.minValue"), null));
		coloring.setMidValue(Values.getFloat(cc.getPropertyValue("coloring.midValue"), null));
		coloring.setMaxValue(Values.getFloat(cc.getPropertyValue("coloring.maxValue"), null));
		
		currentRawDataType = currentRawDataType != null ? currentRawDataType : defaultRawDataType;
	}
	else
	{
		formula = Formula.getById(dc, itemId);
		currentParser = formula.getParser();
		currentAverageMethod = formula.getAverageMethod();
		currentType = formula.getFormulaType();
		currentRawDataType = formula.getRawDataType();
		expressions = formula.getFormulas();
		coloring = formula.getColoring();
		cc.setObject("item", formula);
		title = "Edit formula -- " + HTML.encodeTags(formula.getName());
	}
	if (formula != null) formula.checkPermission(Permission.WRITE);
	
	final String clazz = "class=\"text\"";
	final String requiredClazz = "class=\"text required\"";
	%>
	<base:page type="popup" title="<%=title%>">
	<base:head scripts="tabcontrol.js" styles="tabcontrol.css">
		<script language="JavaScript">
		// Validate the "Formula" tab
		function validateFormula()
		{
			var frm = document.forms['formula'];
			if (Main.trimString(frm.name.value) == '')
			{
				alert("You must enter a name");
				frm.name.focus();
				return false;
			}
			var type = frm.type[frm.type.selectedIndex].value;
			var numFormulas = frm.expressions.length;
			var numChannels = frm.channels.value;
			if (type == '<%=Formula.Type.INTENSITY_EXPRESSION.name()%>' || type == '<%=Formula.Type.INTENSITY_TRANSFORMATION.name()%>')
			{
				// One formula per channel required
				if (numFormulas != numChannels)
				{
					alert('You must enter one formula for each channel for type = ' + frm.type[frm.type.selectedIndex].text);
					return false;
				}
			}
			else
			{
				// Only one formula can be specified
				if (numFormulas != 1)
				{
					alert('You can only enter one formula for type = ' + frm.type[frm.type.selectedIndex].text);
					return false;
				}
			}
			
			if (frm.use_colors.checked && !frm.use_colors.disabled)
			{
				var minValue = parseFloat(frm.min_value.value);
				var midValue = parseFloat(frm.mid_value.value);
				var maxValue = parseFloat(frm.max_value.value);
				if (isNaN(minValue))
				{
					alert('No min value has been specified');
					frm.min_value.focus();
					return false;
				}
				if (isNaN(midValue))
				{
					alert('No mid value has been specified');
					frm.mid_value.focus();
					return false;
				}
				if (isNaN(maxValue))
				{
					alert('No max value has been specified');
					frm.max_value.focus();
					return false;
				}
				if (minValue > midValue)
				{
					alert('The min value (' + minValue + ') can\'t be greater than the mid value (' + midValue + ')');
					return false;
				}
				if (midValue > maxValue)
				{
					alert('The mid (' + midValue + ') value can\'t be greater than the max value (' + maxValue + ')');
					return false;
				}
			}
			return true;
		}

		// Submit the form
		function saveSettings()
		{
			var frm = document.forms['formula'];
			if (TabControl.validateActiveTab('settings'))
			{
				for (var i = 0; i < frm.expressions.length; i++)
				{
					Forms.createHidden(frm, 'formulas', frm.expressions[i].text);
				}
				frm.channels.disabled = false; // Otherwise the channels info, isn't sent
				frm.submit();
			}
		}
		
		function init()
		{
			<%
			if (formula == null)
			{
				%>
				var frm = document.forms['formula'];
				frm.name.focus();
				frm.name.select();
				<%
			}
			%>
			formulaTypeOnChange();
		}
		var rawDataTypes = new Array();
		<%
		for (RawDataType rdt : RawDataTypes.getRawDataTypes())
		{
			%>
			rawDataTypes['<%=rdt.getId()%>'] = <%=rdt.getChannels()%>;
			var a = new Array();
			<%
			for (RawDataProperty rp : rdt.getProperties())
			{
				%>
				a['<%=rp.getName()%>'] = 1;
				<%
			}
			%>
			rawDataTypes['<%=rdt.getId()%>.properties'] = a;
			<%
		}
		%>
		
		function rawDataTypeOnChange()
		{
			var frm = document.forms['formula'];
			var rdt = frm.rawdatatype[frm.rawdatatype.selectedIndex].value;
			if (rdt != '')
			{
				frm.channels.value = rawDataTypes[rdt];
				frm.channels.disabled = true;
				Main.addClass(frm.channels, 'disabled');
				Main.removeClass(frm.channels, 'required');
			}
			else
			{
				frm.channels.disabled = false;
				Main.removeClass(frm.channels, 'disabled');
				Main.addClass(frm.channels, 'required');
			}
		}

		var selectedExpressionIndex = -1;
		function expressionsOnClick()
		{
			var frm = document.forms['formula'];
			selectedExpressionIndex = frm.expressions.selectedIndex;
			frm.expression.value = frm.expressions[selectedExpressionIndex].text;
		}

		function expressionOnBlur()
		{
			var frm = document.forms['formula'];
			if (selectedExpressionIndex >= 0)
			{
				frm.expressions[selectedExpressionIndex].text = frm.expression.value;
			}
		}
		
		function removeOnClick()
		{
			var frm = document.forms['formula'];
			if (selectedExpressionIndex >= 0)
			{
				frm.expressions[selectedExpressionIndex] = null;
				selectedExpressionIndex = -1;
			}
		}
		
		function addOnClick()
		{
			var frm = document.forms['formula'];
			if (frm.expression.value != '')
			{
				frm.expressions[frm.expressions.length] = new Option(frm.expression.value);
				selectedExpressionIndex = frm.expressions.length - 1;
				frm.expressions.selectedIndex = selectedExpressionIndex;
			}
		}
		
		function openExpressionBuilder()
		{
			var frm = document.forms['formula'];
			var rdt = frm.rawdatatype[frm.rawdatatype.selectedIndex].value;
			var formulaType = frm.type[frm.type.selectedIndex].value;
			var channels = frm.channels.value;
			var restrictions = formulaType == '<%=Formula.Type.COLUMN_RESTRICTION.name()%>';
			Main.expressionBuilder('<%=ID%>', 'Expression', 'formula', 'expression', formulaType, rdt, channels, restrictions, null, 'setExpressionFromBuilder');
		}
	
		function setExpressionFromBuilder(form, textarea, value)
		{
			var frm = document.forms['formula'];
			frm[textarea].value = value;
			if (frm.expressions.length == 0) 
			{
				addOnClick();
			}
			else
			{
				expressionOnBlur();
			}
		}
	
		var useColors = new Array();
		var supportsAverage = new Array();
		<%
		for (Formula.Type ft : Formula.Type.values())
		{
			%>
			useColors['<%=ft.name()%>'] = <%=ft.canUseColoring()%>;
			supportsAverage['<%=ft.name()%>'] = <%=ft.supportsAverage()%>;
			<%
		}
		%>
	
		function useColorsOnClick()
		{
			var frm = document.forms['formula'];
			var useColors = frm.use_colors.checked && !frm.use_colors.disabled;
			frm.min_value.disabled = !useColors;
			frm.mid_value.disabled = !useColors;
			frm.max_value.disabled = !useColors;
			frm.logarithmic.disabled = !useColors;
			if (useColors)
			{
				Main.addClass(frm.min_value, 'required');
				Main.addClass(frm.mid_value, 'required');
				Main.addClass(frm.max_value, 'required');
			}
			else
			{
				Main.removeClass(frm.min_value, 'required');
				Main.removeClass(frm.mid_value, 'required');
				Main.removeClass(frm.max_value, 'required');
			}
		}
		
		function formulaTypeOnChange()
		{
			var frm = document.forms['formula'];
			var formulaType = frm.type[frm.type.selectedIndex].value;
			var use = useColors[formulaType];
			frm.use_colors.disabled = !use;
			useColorsOnClick();
			var supportsAvg = supportsAverage[formulaType];
			frm.averageMethod.disabled = !supportsAvg;
			if (!supportsAvg) frm.averageMethod.selectedIndex = 0;
		}
		</script>
	</base:head>
	<base:body onload="init()">
		<p>
		<form action="index.jsp?ID=<%=ID%>" method="post" name="formula" onsubmit="return false;">
		<input type="hidden" name="cmd" value="UpdateItem">

		<h3 class="docked"><%=title%> <base:help tabcontrol="settings" /></h3>
		<t:tabcontrol id="settings" contentstyle="<%="height: "+(int)(scale*380)+"px;"%>" 
			position="bottom"  remember="<%=formula != null%>">
		<t:tab id="info" title="Formula" validate="validateFormula()" helpid="formula.edit">
			<table class="form" cellspacing=0>
			<tr>
				<td class="prompt">Name</td>
				<td><input <%=requiredClazz%> type="text" name="name" 
					value="<%=HTML.encodeTags(formula == null ? Values.getString(cc.getPropertyValue("name"), "New formula") : formula.getName())%>" 
					size="40" maxlength="<%=Formula.MAX_NAME_LENGTH%>"></td>
			</tr>
			<tr>
				<td class="prompt">Type</td>
				<td>
					<select name="type" class="required" onchange="formulaTypeOnChange()">
					<%
					for (Formula.Type type : Formula.Type.values())
					{
						String selected = type == currentType ? "selected" : "";
						%>
						<option value="<%=type.name()%>" <%=selected%>><%=HTML.encodeTags(type.toString())%>
						<%
					}
					%>
					</select>
				</td>
			</tr>
			<tr>
				<td class="prompt">Parser</td>
				<td>
					<select name="parser" class="required">
					<%
					for (Formula.Parser parser : Formula.Parser.values())
					{
						String selected = parser == currentParser ? "selected" : "";
						%>
						<option value="<%=parser.name()%>" <%=selected%>><%=HTML.encodeTags(parser.toString())%>
						<%
					}
					%>
					</select>
				</td>
			</tr>
			<tr>
				<td class="prompt">Raw data type</td>
				<td>
					<select name="rawdatatype" onchange="rawDataTypeOnChange()">
					<option value="">- none -
					<%
					for (RawDataType rdt : RawDataTypes.getRawDataTypes())
					{
						String selected = rdt == currentRawDataType ? "selected" : "";
						%>
						<option value="<%=rdt.getId()%>" <%=selected%>><%=HTML.encodeTags(rdt.getName())%>
						<%
					}
					%>
					</select>
				</td>
			</tr>
			<tr>
				<td class="prompt">Channels</td>
				<td><input <%=currentRawDataType != null ? "class=\"text disabled\" disabled" : requiredClazz%> type="text" name="channels" 
					value="<%=formula == null ? (currentRawDataType == null ? Values.getInt(cc.getPropertyValue("channels")) : currentRawDataType.getChannels()) : formula.getChannels()%>" 
					size="12" maxlength="10" onkeypress="return Numbers.integerOnly(event)"
					></td>
			</tr>
			<tr valign="top">
				<td class="prompt">Expressions</td>
				<td>
					<table border="0" cellspacing="0" cellpadding="2">
					<tr>
						<td>
						<select name="expressions" size="3" style="width: 26em;"
							onchange="expressionsOnClick()" multiple class="required">
							<%
							if (expressions != null)
							{
								for (String expression : expressions)
								{
									%>
									<option><%=HTML.encodeTags(expression)%>
									<%
								}
							}
							%>
						</select>
						</td>
						<td><base:button onclick="removeOnClick()" title="Remove" /></td>
					</tr>
					<tr>
					<td>
						<input type="text" name="expression" class="text" style="width: 26em;"
							maxlength="<%=Formula.MAX_FORMULA_LENGTH%>"
							onblur="expressionOnBlur()">
					</td>
					<td>
						<base:button onclick="addOnClick()" title="Add" />
					</td>
					<td>
						<base:button onclick="openExpressionBuilder()" 
							image="expression_builder.gif"
							title="Expression builder&hellip;" />
					</td>
					</table>
				</td>
			</tr>
			<tr>
				<td class="prompt">Avg. method</td>
				<td>
					<select name="averageMethod" class="required">
					<%
					for (Formula.AverageMethod method : Formula.AverageMethod.values())
					{
						String selected = method == currentAverageMethod ? "selected" : "";
						%>
						<option value="<%=method.name()%>" <%=selected%>><%=HTML.encodeTags(method.toString())%>
						<%
					}
					%>
					</select>
				</td>
			</tr>
			
			<tr>
				<td class="prompt">Use colors</td>
				<td>
					<input type="checkbox" name="use_colors" value="1" 
						<%=coloring.isUsingColors() ? "checked" : "" %>
						onclick="useColorsOnClick()">
					
					<b>Min value</b>
					<input type="text" class="text" name="min_value"
						 value="<%=Values.formatNumber(coloring.getMinValue(), -1)%>"
						 size="6" maxlength="6"
						 onkeypress="return Numbers.numberOnly(event)"
						 >
					<b>Mid value</b>
					<input type="text" class="text" name="mid_value"
						 value="<%=Values.formatNumber(coloring.getMidValue(), -1)%>"
						 size="6" maxlength="6"
						 onkeypress="return Numbers.numberOnly(event)"
						 >
					<b>Max value</b>
					<input type="text" class="text" name="max_value"
						 value="<%=Values.formatNumber(coloring.getMaxValue(), -1)%>"
						 size="6" maxlength="6"
						 onkeypress="return Numbers.numberOnly(event)"
						 >
						 <br>
					<input type="checkbox" name="logarithmic" value="1" 
						<%=coloring.isLogarithmic() ? "checked" : "" %>>
					<b>Logarithmic</b>
				</td>
			</tr>

			<tr valign=top>
				<td class="prompt">Description</td>
				<td nowrap>
					<textarea <%=clazz%> rows="4" cols="40" name="description" wrap="virtual"
						><%=HTML.encodeTags(formula == null ? cc.getPropertyValue("description") : formula.getDescription())%></textarea>
					<a href="javascript:Main.zoom('Description', 'formula', 'description')"
						title="Edit in larger window"><base:icon image="zoom.gif" /></a>
				</td>
			</tr>
			</table>
			<div align=right>&nbsp;<i><base:icon image="required.gif" /> = required information</i></div>
		</t:tab>
		</t:tabcontrol>

		<table align="center">
		<tr>
			<td width="50%"><base:button onclick="saveSettings()" title="Save" /></td>
			<td width="50%"><base:button onclick="window.close()" title="Cancel" /></td>
		</tr>
		</table>
		</form>
	</base:body>
	</base:page>
	<%
}
finally
{
	if (dc != null) dc.close();
}
%>
